#
# spec file for package cockpit-agama
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cockpit-agama
Version:        7+0
Release:        7.3
Summary:        Cockpit module for Agama
License:        GPL-2.0-only
URL:            https://github.com/openSUSE/agama
# source_validator insists that if obscpio has no version then
# tarball must neither
Source0:        agama.tar
Source10:       package-lock.json
Source11:       node_modules.spec.inc
Source12:       node_modules.sums
%include %_sourcedir/node_modules.spec.inc
BuildArch:      noarch
Requires:       cockpit
BuildRequires:  appstream-glib
BuildRequires:  cockpit
BuildRequires:  cockpit-devel >= 243
BuildRequires:  local-npm-registry

%description
Cockpit module for the experimental Agama installer.

%prep
%autosetup -p1 -n agama
rm -f package-lock.json
local-npm-registry %{_sourcedir} install --with=dev --legacy-peer-deps || ( find ~/.npm/_logs -name '*-debug.log' -print0 | xargs -0 cat; false)

%build
# cp -r %{_datadir}/cockpit/devel/lib src/lib
NODE_ENV="production" npm run build

%install
%make_install

%check
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*

%files
%doc README.md
%{_datadir}/cockpit
%{_datadir}/metainfo/*

%changelog
* Fri Dec 22 2023 David Diaz <dgonzalez@suse.com>
- UI: Fix page menus placement in production mode,
  rendering them in the page header (gh#openSUSE/agama#925,
  gh#openSUSE/agama#950).
* Thu Dec 21 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 7
* Thu Dec 21 2023 David Diaz <dgonzalez@suse.com>
- Rework UI internals for improving core/Page component and changing
  how layout is handled (gh#openSUSE/agama#925).
- Drop layout/Layout and stop using react-teleporter.
* Thu Dec 21 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- Display countries at timezone selector (gh#openSUSE/agama#946).
* Mon Dec 18 2023 José Iván López González <jlopez@suse.com>
- Do not show info icon for the file system label if there is only
  one option (gh#openSUSE/agama#938).
* Fri Dec 15 2023 José Iván López González <jlopez@suse.com>
- Allow selecting file system type and configure snapshots
  (gh#openSUSE/agama/926).
* Sat Dec  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 6
* Thu Nov 30 2023 David Diaz <dgonzalez@suse.com>
- UI: make selectors more compact (gh#openSUSE/agama#898).
* Thu Nov 30 2023 José Iván López González <jlopez@suse.com>
- Allow selecting the storage policy to make free space for the
  installation (gh#openSUSE/agama#883).
* Wed Nov 29 2023 José Iván López González <jlopez@suse.com>
- Allow selecting language, keymap and timezone for the target
  system (gh#openSUSE/agama#881).
* Wed Nov 29 2023 David Diaz <dgonzalez@suse.com>
- UI: improve the look and feel by fine tunning the sections spacing,
  alignment, and icon sizes (gh#openSUSE/agama#892).
* Tue Nov 21 2023 David Diaz <dgonzalez@suse.com>
- UI: Do not crash when clicking the install button. It started
  failing after removing core-js dependency (gh#openSUSE/agama#880
  and related to gh#openSUSE/agama#866).
* Fri Nov 17 2023 David Diaz <dgonzalez@suse.com>
- UI: Fix broken storage links (bsc#1217281).
* Wed Nov 15 2023 José Iván López González <jlopez@suse.com>
- Add UI for registering a product (gh#openSUSE/agama#869).
* Thu Nov  2 2023 David Diaz <dgonzalez@suse.com>
- UI: Drop support for opening dialogs directly from a section
  header (gh#openSUSE/agama#838).
* Tue Oct 31 2023 David Diaz <dgonzalez@suse.com>
- UI: sections improvements (gh#openSUSE/agama#816):
  - allow using them without title.
  - make them more accessible by using aria-label, aria-live-region,
    and aria-busy attributes.
* Fri Oct 27 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Display the "Congratulations" message at the end of the
  installation again (gh#openSUSE/agama#825).
* Thu Oct 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Properly track the status changes. It prevents of getting stuck
  in the first page when there are multiple products
  (gh#openSUSE/agama#821).
* Thu Oct 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Make sure that the software context is ready before trying to
  load any route (gh#openSUSE/agama#820).
* Thu Oct 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix client initialization to avoid a useless reconnection
  (gh#openSUSE/agama#819).
* Mon Oct 23 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 5
* Thu Oct 19 2023 David Diaz <dgonzalez@suse.com>
- UI: fix CSS rule for applying grayscale and blur CSS filters to
  main wrapper when the sidebar is open (gh#openSUSE/agama#802).
* Tue Oct 17 2023 Imobach González Sosa <igonzalezsosa@suse.com>
- Allow changing the language of the user interface
  (gh#openSUSE/agama#796).
* Tue Oct 10 2023 Ladislav Slezák <lslezak@suse.com>
- Added pattern selector to allow changing the installed software
  (gh#openSUSE/agama#792)
* Mon Oct  9 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Reload only once when changing the language using the lang=
  parameter in the query string (gh#openSUSE/agama#794).
* Thu Oct  5 2023 Josef Reidinger <jreidinger@suse.com>
- Add flag if volume is transactional btrfs (gh#openSUSE/agama#789)
* Thu Oct  5 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Implement a mechanism to reconnect to the D-Bus service
  (gh#openSUSE/agama#781).
* Mon Oct  2 2023 David Diaz <dgonzalez@suse.com>
- UI: migrate to PatternFly 5 (gh#openSUSE/agama#759)
* Fri Sep 29 2023 David Diaz <dgonzalez@suse.com>
- Do not drop source maps from production build
  (gh#openSUSE/agama#779)
* Wed Sep 27 2023 José Iván López González <jlopez@suse.com>
- Allow to select the devices for the system volume group
  (gh#openSUSE/agama#763).
* Tue Sep 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 4
* Tue Sep 19 2023 Balsa Asanovic <balsaasanovic95@gmail.com>
- Allow users to show password values (gh#openSUSE/agama#750).
* Tue Sep 19 2023 José Iván López González <jlopez@suse.com>
- Explicitly call to probe after selecting a new product
  (gh#openSUSE/agama#748).
* Thu Sep 14 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single D-Bus service to connect to the manager and the
  users API (gh#openSUSE/agama#753, follow-up of
  gh#openSUSE/agama#729).
* Mon Sep 11 2023 David Diaz <dgonzalez@suse.com>
- Fix the download logs action in the web UI (gh#openSUSE/agama#697)
* Wed Sep  6 2023 José Iván López González <jlopez@suse.com>
- Adapt storage to new proposal settings (gh#openSUSE/agama#738).
* Thu Aug 31 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Adapt the locale and questions clients to use the same D-Bus
  service (gh#openSUSE/agama#729).
* Sat Aug 12 2023 Balsa Asanovic <balsaasanovic95@gmail.com>
- Added scroll up functionality to the discover iSCSI form when
  the warning shows up after the submit action
  (gh#openSUSE/agama#468).
* Wed Aug  2 2023 Balsa Asanovic <balsaasanovic95@gmail.com>
- Introduced functionality to close Dropdown automatically
  when the user clicks outside of it.
  (gh#openSUSE/agama#552).
* Wed Aug  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 3
* Mon Jul 17 2023 Josef Reidinger <jreidinger@suse.com>
- Adapt to new questions D-Bus API to allow automatic answering of
  questions when requested. No visible change in UI, just default
  answer for LUKS partition activation is now "Skip".
  (gh#openSUSE/agama#637)
* Wed Jul  5 2023 José Iván López González <jlopez@suse.com>
- Add info about deactivated zFCP auto_lun_scan and sort members in
  device selector (gh#openSUSE/agama#650).
* Mon Jul  3 2023 José Iván López González <jlopez@suse.com>
- Add page for managing zFCP devices (gh#openSUSE/agama#634).
* Wed Jun 21 2023 Balsa Asanovic <balsaasanovic95@gmail.com>
- Moved the logic for adding and removing HTML element's
  attributes from sidebar component to custom hook
  (gh#openSUSE/agama#565).
* Tue Jun 13 2023 David Diaz <dgonzalez@suse.com>
- UI: stop using fixed sizes for modal dialogs
  (gh#openSUSE/agama#620).
* Tue Jun 13 2023 David Diaz <dgonzalez@suse.com>
- Storage: adjust volume size options wording and size
  (gh#/openSUSE/agama#618).
* Mon Jun 12 2023 David Diaz <dgonzalez@suse.com>
- UI: makes more evident when there is none authentication method
  defined for the root user (gh#openSUSE/agama#615).
* Fri Jun  9 2023 David Diaz <dgonzalez@suse.com>
- Storage: allow setting the volume size (gh#openSUSE/agama#590).
* Wed May 24 2023 David Diaz <dgonzalez@suse.com>
- UI: ensure that blur and grayscale CSS filters are not applied to
  any nodes other than <body> direct children (gh#openSUSE/agama#588).
* Tue May 23 2023 Martin Vidner <mvidner@suse.com>
- Version 2.1
* Tue May 23 2023 José Iván López González <jlopez@suse.com>
- Add new component for selecting devices.
- gh#openSUSE/agama#586
* Mon May 22 2023 Martin Vidner <mvidner@suse.com>
- Version 2
* Mon May 22 2023 David Diaz <dgonzalez@suse.com>
- UI: Fix header and footer block size (gh#openSUSE/agama#583)
* Fri May 19 2023 David Diaz <dgonzalez@suse.com>
- UI: grayscale and blur not accessible div nodes
  (gh#openSUSE/agama#564)
* Wed May 17 2023 David Diaz <dgonzalez@suse.com>
- Ensure siblings of an open modal dialog do not remain hidden from
  the accessibility API if the dialog is unmounted instead of
  set as closed (gh#openSUSE/agama#580).
* Tue May  9 2023 David Diaz <dgonzalez@suse.com>
- Keep the sidebar on top of other elements when it's open
  (gh#openSUSE/agama#569).
* Mon May  8 2023 David Diaz <dgonzalez@suse.com>
- Set sidebar siblings as aria-hiden while it's open
  (gh#openSUSE/agama#563)
* Fri Apr 28 2023 José Iván López González <jlopez@suse.com>
- Add issues for storage client.
- Add issues page.
- gh#openSUSE/agama#540
* Thu Apr 27 2023 Ladislav Slezák <lslezak@suse.com>
- Display details for the "autocalculated" label in the storage
  settings
* Tue Apr 25 2023 David Diaz <dgonzalez@suse.com>
- UI: Fix dropdown content alignment at storage proposal page
  (gh#openSUSE/agama#547).
* Tue Apr 25 2023 David Diaz <dgonzalez@suse.com>
- UI: Do not indent sections without icons (gh#openSUSE/agama#549).
* Mon Apr 24 2023 David Diaz <dgonzalez@suse.com>
- Extract page options from the Sidebar to make them
  more discoverable (gh#openSUSE/agama#545)
* Thu Apr 20 2023 David Diaz <dgonzalez@suse.com>
- Make styles consistent when the user is hovering a button,
  no matter if it is a focus state or not (gh#openSUSE/agama#544).
* Fri Apr 14 2023 José Iván López González <jlopez@suse.com>
- First steps for redesigning storage proposal UI:
  * Place settings directly on the proposal page.
  * Show list of file systems, allowing to add and remove.
- gh#openSUSE/agama#521
* Tue Apr 11 2023 Knut Anderssen <kanderssen@suse.com>
- Fix netmask handling (bsc#1210104).
* Wed Apr  5 2023 José Iván López González <jlopez@suse.com>
- Fix issues with questions client (gh#openSUSE/agama#524).
* Mon Apr  3 2023 Knut Anderssen <kanderssen@suse.com>
- Fix DNS handling by using ipv4.dns-data instead of ipv4.dns (gh#openSUSE/agama#518).
* Wed Mar 29 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Rename D-Installer to Agama (gh#openSUSE/agama#507).
- Version 1
* Fri Mar 24 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.8.3
* Fri Mar 24 2023 Knut Alejandro Anderssen González <kanderssen@suse.com>
- Add UI for configuring DASD (gh#openSUSE/agama#501).
* Fri Mar 24 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- Added a tip about iSCSI and DASD configuration to the storage
  page (gh#openSUSE/agama#500).
* Fri Mar 24 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.8.2
* Thu Mar 23 2023 José Iván López González <jlopez@suse.com>
- Reprobe storage if the system becomes deprecated
  (gh#openSUSE/agama#484).
* Tue Mar 21 2023 Ladislav Slezák <lslezak@suse.com>
- Do not crash when setting an invalid target device using the
  command line interface (bsc#1209523)
* Mon Mar 20 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Upgrade Webpack to version 5.76.2 (CVE-2023-28154, bsc#1209494).
- Version 0.8.1
* Mon Mar 20 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Remove the redundant "Settings" suffix (gh#openSUSE/agama#481).
* Mon Mar 20 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the initialization of the D-Bus iSCSI proxies
  (gh#openSUSE/agama#478).
* Mon Mar 20 2023 José Iván López González <jlopez@suse.com>
- Fix the iSCSI discover form when no information is found in the
  browser's local storage (gh#openSUSE/agama#475).
* Thu Mar 16 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.8
* Thu Mar 16 2023 José Iván López González <jlopez@suse.com>
- Add UI for configuring iSCSI (gh#openSUSE/agama#435).
* Mon Mar 13 2023 David Diaz <dgonzalez@suse.com>
- Sidebar improvements (gh#openSUSE/agama#462)
  * Allow adding actions from a page.
  * Remove network information.
  * Use underlined links and darker green color for improving contrast.
  * Start using a disclosure widget for grouping related actions.
* Fri Mar  3 2023 David Diaz <dgonzalez@suse.com>
- Enhance the user edit form (gh#openSUSE/agama#451).
* Thu Mar  2 2023 David Diaz <dgonzalez@suse.com>
- Dependencies update (gh#openSUSE/agama#449).
  * Go up to React 18.
  * Bring node packages up to date.
* Wed Mar  1 2023 David Diaz <dgonzalez@suse.com>
- Create a dedicated page per section
  (gh#openSUSE/agama#443).
* Tue Feb 21 2023 David Diaz <dgonzalez@suse.com>
- Set icons as aria-hidden (gh#openSUSE/agama#437).
* Mon Feb 20 2023 David Diaz <dgonzalez@suse.com>
- Sidebar improvements (gh#openSUSE/agama#436)
  * Use proper control for open and close actions
  * Improve styling and labels
  * Add missing aria attributes
* Thu Feb 16 2023 Ladislav Slezák <lslezak@suse.com>
- Integrate cockpit terminal application (gh#openSUSE/agama#426)
* Wed Feb 15 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.7
- Do not use a proxy to get the errors lists
  (gh#openSUSE/agama#424).
* Thu Feb  9 2023 David Diaz <dgonzalez@suse.com>
- Add live reloading feature for easing the front-end development
  process (gh#openSUSE/agama#419).
* Thu Feb  9 2023 David Diaz <dgonzalez@suse.com>
- Fix storage section crashing when proposal is not ready
  (gh#openSUSE/agama#418).
* Wed Feb  8 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Better handling of software repositories
  (gh#openSUSE/agama#414):
  * Report issues when reading the software repositories.
  * Inform the user about the software proposal progress.
  * Add a button to reload the repositories
    (gh#openSUSE/agama#388).
* Tue Jan 24 2023 Ladislav Slezák <lslezak@suse.com>
- Added a button for displaying the YaST logs
  (related to gh#openSUSE/agama#379)
* Fri Jan 20 2023 David Diaz <dgonzalez@suse.com>
- UI fixes (gh#openSUSE/agama#401):
  * Add a fallback height for the layout
  * Fix some miss-alignments
  * Add missing icon
  * Ensure tooling serving and loading fonts
* Thu Jan 19 2023 David Diaz <dgonzalez@suse.com>
- Update aliases for using "~/" instead of "@"
  (gh#openSUSE/agama#400).
* Wed Jan 18 2023 Josef Reidinger <jreidinger@suse.com>
- Allow user downloading logs (gh#openSUSE/agama#379)
* Thu Jan 12 2023 Josef Reidinger <jreidinger@suse.com>
- Implement validation of software proposal to early detect
  issues in software selection (gh#openSUSE/agama#381)
* Wed Jan 11 2023 David Diaz <dgonzalez@suse.com>
- Testing: use a mocking function to make mocked components
  consistent across the test suite (gh#openSUSE/agama#392).
* Wed Jan 11 2023 David Diaz <dgonzalez@suse.com>
- Rework UI internals by using plain CSS as much as possible for
  building the layout instead of relying on wrapper components
  (gh#openSUSE/agama#391).
* Tue Jan 10 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Connect to the dedicated D-Bus server (gh#openSUSE/agama#384).
* Mon Jan  2 2023 David Diaz <dgonzalez@suse.com>
- Add missing favicon (gh#openSUSE/agama#387).
* Mon Jan  2 2023 Knut Anderssen <kanderssen@suse.com>
- Do not show the link to configure wifi networks when there are no
  wifi devices and also inform the user when no network connection
  was detected (gh#openSUSE/agama#323).
- Version 0.6.3
* Mon Jan  2 2023 David Diaz <dgonzalez@suse.com>
- Ensure custom fonts are including in the build
  (gh#openSUSE/agama#385).
* Fri Dec 30 2022 David Diaz <dgonzalez@suse.com>
- Switch to Material Symbols icon set and refactor how icons
  are imported (gh#openSUSE/agama#383).
* Thu Dec 15 2022 Knut Anderssen <kanderssen@suse.com>
- Do not show the link to configure wifi networks when wireless is
  not enabled (gh#openSUSE/agama#323).
- Version 0.6.2
* Thu Dec 15 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Display questions during the software installation (related to
  gh#openSUSE/agama#369).
- Update to version 0.6.1
* Mon Dec  5 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.6.0
* Fri Dec  2 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for password confirmation
  (related to gh#openSUSE/agama#297)
* Fri Dec  2 2022 José Iván López González <jlopez@suse.com>
- Add new UI for storage proposal offering LVM and encyption
  options (gh#openSUSE/agama#321).
* Fri Dec  2 2022 Josef Reidinger <jreidinger@suse.cz>
- Add support for adapting the configuration depending on the
  architecture (gh#openSUSE/agama#339)
* Wed Nov 30 2022 Knut Alejandro Anderssen González <kanderssen@suse.de>
- Add validation for the first user creation (gh#openSUSE/agama#337)
* Fri Nov 18 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.5.0:
  * Add support for basic network configuration, based on
    NetworkManager (gh#openSUSE/agama#260, gh#openSUSE/agama#292).
  * Improve the usability of the LUKS activation dialog
    (gh#openSUSE/agama#253).
  * Prevent starting the installation with incomplete or wrong
    configuration (gh#openSUSE/agama#299).
* Thu Jul 28 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.4.2:
  * Connect to the org.opensuse.DInstaller.Language service
    (related to gh#openSUSE/agama#240).
* Tue Jul 26 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.4.1:
  * Fix several user interface-related issues (gh#openSUSE/agama#230):
  - Avoid reloading the page when pushing the enter key.
  - Always display the D-Bus error page when the connection gets
    broken. Reload the UI again when the D-Bus connection is
    working again.
  - Update the product selection page when the product is
    modified in background (e.g., using the CLI).
  - Update the first user settings when they are changed in
    background.
  - Refresh the storage section when the settings are modified
    in background.
  - If the storage proposal fails, display the error even after
    reloading the page.
* Fri Jul 15 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.4:
  * Support for installing multiple products
    (gh#openSUSE/agama#211).
  * Adapt to the new status/progress reporting API
    (gh#openSUSE/agama#219).
  * Add a better layout mechanism (gh#openSUSE/agama#216).
* Mon Jun 13 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.3:
  * Refresh the web UI when a selected option changes (e.g., through
    the CLI) (gh#openSUSE/agama#180).
  * Remove the "Restart Installation" button
    (gh#openSUSE/agama#167 and gh#openSUSE/agama#174).
  * Add a task to generate the JSDoc-based documentation
    (gh#openSUSE/agama#186 and gh#openSUSE/agama#191).
* Tue May 17 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to version 0.2:
  * Turn the web UI into a Cockpit module (gh#openSUSE/agama#127)
    and drop the authentication code (gh#openSUSE/agama#128).
  * Add basic storage devices activation (gh#openSUSE/agama#150).
  * Fix the behavior of the language selector
    (gh#openSUSE/agama#125).
  * Add an installation confirmation dialog
    (gh#openSUSE/agama#118) and a reboot button
    (gh#openSUSE/agama#114).
* Wed Mar 30 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- First release (version 0.1):
  * Allow setting the language, selecting a product, choosing a disk to
    install into, setting the root authentication mechanism and creating
    a first user.
  * Report installation progress.
  * Communication with D-Bus through Cockpit's infrastructure.
